==> haskell-puremd5-2.1.3-20-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-puremd5.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pureMD5
version: 2.1.3
id: pureMD5-2.1.3-GWHbwGd6W0K3oa7w99njIp
key: pureMD5-2.1.3-GWHbwGd6W0K3oa7w99njIp
license: BSD-3-Clause
maintainer: Thomas DuBuisson
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
synopsis: A Haskell-only implementation of the MD5 digest (hash) algorithm.
description:
    A Haskell-only implementation of the MD5 digest (hash) algorithm.  This now supports
    the crypto-api class interface.
category: Data, Cryptography
abi: b42f838a83ad8e457f1a37992b4914ef
exposed: True
exposed-modules:
    Data.Digest.Pure.MD5
import-dirs: /usr/lib/ghc-8.6.3/site-local/pureMD5-2.1.3
library-dirs: /usr/lib/ghc-8.6.3/site-local/pureMD5-2.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/pureMD5-2.1.3
hs-libraries: HSpureMD5-2.1.3-GWHbwGd6W0K3oa7w99njIp
depends:
    base-4.12.0.0 binary-0.8.6.0 bytestring-0.10.8.2
    cereal-0.5.7.0-GJYlaDDl5qNLbZMZyr0ENN
    crypto-api-0.13.3-21SCCuzTBNCKm1vzPpKkiO
    tagged-0.8.6-FABECvKnqYbBCttH1EeJvB
haddock-interfaces: /usr/share/doc/haskell-puremd5/html/pureMD5.haddock
haddock-html: /usr/share/doc/haskell-puremd5/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-puremd5-2.1.3-21-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-puremd5.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pureMD5
version: 2.1.3
id: pureMD5-2.1.3-6o5vklUj0TIByhaiKLbF7e
key: pureMD5-2.1.3-6o5vklUj0TIByhaiKLbF7e
license: BSD-3-Clause
maintainer: Thomas DuBuisson
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
synopsis: A Haskell-only implementation of the MD5 digest (hash) algorithm.
description:
    A Haskell-only implementation of the MD5 digest (hash) algorithm.  This now supports
    the crypto-api class interface.
category: Data, Cryptography
abi: dd33d59cd5993e5a71e5e95e062a6b78
exposed: True
exposed-modules:
    Data.Digest.Pure.MD5
import-dirs: /usr/lib/ghc-8.6.3/site-local/pureMD5-2.1.3
library-dirs: /usr/lib/ghc-8.6.3/site-local/pureMD5-2.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/pureMD5-2.1.3
hs-libraries: HSpureMD5-2.1.3-6o5vklUj0TIByhaiKLbF7e
depends:
    base-4.12.0.0 binary-0.8.6.0 bytestring-0.10.8.2
    cereal-0.5.8.0-DifhRWa8By0JYDe2id7eOT
    crypto-api-0.13.3-IANbrPH7VZx9nBEsnLhELk
    tagged-0.8.6-FABECvKnqYbBCttH1EeJvB
haddock-interfaces: /usr/share/doc/haskell-puremd5/html/pureMD5.haddock
haddock-html: /usr/share/doc/haskell-puremd5/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
